MssqlConnection

Struct MssqlConnection 

pub struct MssqlConnection { /* private fields */ }
MSSQL connection backed by an actor thread that owns the ODBC connection.

Implementations

Source

impl MssqlConnection

pub fn connect_blocking( options: &MssqlConnectOptions, ) -> Result<MssqlConnection, MssqlError>

Opens a blocking MSSQL ODBC connection with the provided options and spawns an actor thread to own it.

pub fn ping_blocking(&self) -> Result<(), Error>

Executes a minimal connectivity query.

pub fn dbms_name(&self) -> Result<String, Error>

Returns the DBMS name reported by the ODBC driver.

pub fn prepare_blocking(&self, sql: SqlStr) -> Result<MssqlStatement, Error>

Prepares a statement and returns the metadata reported by the ODBC driver.