pub struct MssqlConnection { /* private fields */ }Expand description
MSSQL connection backed by an actor thread that owns the ODBC connection.
Implementations
Sourceimpl MssqlConnection
impl MssqlConnection
Sourcepub fn connect_blocking(
options: &MssqlConnectOptions,
) -> Result<MssqlConnection, MssqlError>
pub fn connect_blocking( options: &MssqlConnectOptions, ) -> Result<MssqlConnection, MssqlError>
Opens a blocking MSSQL ODBC connection with the provided options and spawns an actor thread to own it.
Sourcepub fn ping_blocking(&self) -> Result<(), Error>
pub fn ping_blocking(&self) -> Result<(), Error>
Executes a minimal connectivity query.
Sourcepub fn dbms_name(&self) -> Result<String, Error>
pub fn dbms_name(&self) -> Result<String, Error>
Returns the DBMS name reported by the ODBC driver.
Sourcepub fn prepare_blocking(&self, sql: SqlStr) -> Result<MssqlStatement, Error>
pub fn prepare_blocking(&self, sql: SqlStr) -> Result<MssqlStatement, Error>
Prepares a statement and returns the metadata reported by the ODBC driver.